# -*- coding: utf-8 -*-
"""
第211回農林交流センターWS「メッシュ農業気象データ利用講習会」 
実習：Pythonによるメッシュ農業気象データの処理１

"""
#Pythonに機能を追加するために外部モジュールをインポートします。
import numpy as np               #配列計算を高速に実行するためのモジュール
import AMD_Tools3 as AMD         #メッシュ農業気象データを利用するためのモジュール



#ちょっと奇妙ですが、プログラムの本文は次の文で始めます。
if __name__ == "__main__":

    # 取得する気象要素の指定
    #  気象要素は、文字列で指定します。 
    nani = "TMP_mea"

    # データを取得する期間の指定
    #  2018年5月1日から9月30日までのデータを取得するには以下のように期間を指定します。
    itsu = ["2018-05-01", "2018-09-30" ]

    # 対象とする地点の指定
    #  北緯36.0566度,東経140.125度の地点を含むメッシュのデータを取得するには場所を以下のように指定します。
    doko = [ 36.0566, 36.0566, 140.125, 140.125]	#つくば(舘野)

    # 気象データの取得
    #　　気象データを取得するGetMetData関数の括弧の中に上記の変数を指定し、右辺に置きます。
    #　　左辺には関数の戻り値を置きます。順に、気象データ、日付、緯度、経度が格納されます。
    met, tim, lat, lon = AMD.GetMetData(nani, itsu, doko)	#気象データを取得
    T = met[:,0,0]  #気象データは常に三次元(日付、緯度、経度)の入れ物に入れられて返されます。それを1次元(日付)の入れ物に入れ替えます。名前は一緒で構いません。
    ntim = len(tim)  #何日分の気象データかを数えます。
    
    #有効積算気温の計算
    Ts = 10.0              #基準温度
    
    Tcc = np.zeros(ntim)   #有効積算気温の入れ物

    # 第１日目（０番目の配列要素）は特別扱いが必要です。
    Tcc[0] = max(T[0]-Ts, 0.0)                                 #     <--------
    print("---", 0, tim[0], T[0], Tcc[0] )
    
    # 第２日目（１番目の配列要素）以降は繰り返し計算が可能です。
    for t in range(1,ntim):
        Tcc[t] = Tcc[t-1] + max(T[t]-Ts, 0.0)                  #     <--------
        print("---", t, tim[t], T[t], Tcc[t] )


"""
練習問題２

 有効積算気温の上限値（950.0℃日）を設定し、それに達する日を計算するにはどのようにすれば
よいでしょう。

回答概要    
    Tccx =950.0                 #有効積算気温の上限値が，950.0℃であることを設定する。

    for文のブロック内に，有効積算気温の上限値を超えた場合に，外の行に移動する文を追加する

        if Tccx <= Tcc[t] :     #if 条件式 : 条件式が真の場合は実行する    
            break               #forループを脱出する

    print()                     #print文で，改行する。
    print(tim[t])               #print文で，この日付を表示する  


修正を加えたものが、aet2.pyに収めてあります。
"""


