# -*- coding: utf-8 -*-
"""
第211回農林交流センターWS「メッシュ農業気象データ利用講習会」 
実習：Pythonによるメッシュ農業気象データの処理１

"""
#Pythonに機能を追加するために外部モジュールをインポートします。
import numpy as np               #配列計算を高速に実行するためのモジュール
import AMD_Tools3 as AMD         #メッシュ農業気象データを利用するためのモジュール



#ちょっと奇妙ですが、プログラムの本文は次の文で始めます。
if __name__ == "__main__":

    # 取得する気象要素の指定
    #  気象要素は、文字列で指定します。 
    nani = "TMP_mea"

    # データを取得する期間の指定
    #  2018年3月1日から7月31日までのデータを取得するには以下のように期間を指定します。
    itsu = ["2018-03-01", "2018-07-31"]                        #     <--------

    # 対象とする地点の指定
    #  北緯36.0566度,東経140.125度の地点を含むメッシュのデータを取得するには場所を以下のように指定します。
    doko = [ 36.0566, 36.0566, 140.125, 140.125]	#つくば(舘野)

    # 気象データの取得
    #　　気象データを取得するGetMetData関数の括弧の中に上記の変数を指定し、右辺に置きます。
    #　　左辺には関数の戻り値を置きます。順に、気象データ、日付、緯度、経度が格納されます。
    met, tim, lat, lon = AMD.GetMetData(nani, itsu, doko)	#気象データを取得
    T = met[:,0,0]  #気象データは常に三次元(日付、緯度、経度)の入れ物に入れられて返されます。それを1次元(日付)の入れ物に入れ替えます。名前は一緒で構いません。
    ntim = len(tim)  #何日分の気象データかを数えます。
    
    #有効積算気温の計算
    Ts = 10.0              #基準温度
    Tccx = 950.0           #有効積算気温の上限値　　                   　
    Tcc = np.zeros(ntim)   #有効積算気温の入れ物
    
    # 最終日(（ntim-1)番目の配列要素）は特別扱いが必要です。
    Tcc[ntim-1]=Tccx                                           #     <--------
    print("---", ntim-1, tim[ntim-1], T[ntim-1], Tcc[ntim-1] ) #     <--------

    # （最終日-１日）(（ntim-2)番目の配列要素）以降は繰り返し計算が可能です。    
    for t in range(ntim-1,0,-1):         #ループを91,90,89、・・・と回す。   <--------
        Tcc[t-1] = Tcc[t] - max(T[t]-Ts, 0.0)                  #     <--------
        print("---", t-1, tim[t-1], T[t-1], Tcc[t-1] )         #     <--------
        if Tcc[t-1] < 0.0 :                                    #     <--------    
            break
        
    print()
    print("定植日は"+tim[t-1].strftime("%Y/%m/%d")+"と推定されます。")  #     <--------

"""
練習問題５
    Python!
    簡単なグラフを書いてみましょう。

import matplotlib.pylab as plt       #グラフを描くためのモジュール

    <中略>

    plt.plot(tim, Tcc)
    plt.xlabel('Date')  
    plt.title("Accumulated Effective Temperature")      
    plt.show()

回答例が、aet5.pyに収めてあります。
"""
